import { Member, Message, Guild } from 'eris';
import { Client, Command } from '.';

export default class Util {
  public client: Client;

  constructor(client: Client) {
    this.client = client;
  }

  get emojis() {
    return {
      SUCCESS: '<:modSuccess:578750988907970567>',
      LOADING: '<a:modloading:588607353935364106>',
      ERROR: '<:modError:578750737920688128>',
    };
  }

  /**
   * Resolves a command
   * @param query Command input
   * @param message Only used to check for errors
   */
  public resolveCommand(query: string | string[]): Promise<{cmd: Command, args: string[] }> {
    try {
      // let resolvedCommand: Command;
      // eslint-disable-next-line no-param-reassign
      if (typeof query === 'string') query = query.split(' ');
      const commands = this.client.commands.toArray();
      const resolvedCommand = commands.find((c) => c.name === query[0].toLowerCase() || c.aliases.includes(query[0].toLowerCase()));

      if (!resolvedCommand) return Promise.resolve(null);
      query.shift();
      return Promise.resolve({ cmd: resolvedCommand, args: query });
    } catch (error) {
      return Promise.reject(error);
    }
  }

  public resolveMember(message: Message, search: string, guild: Guild): Member | undefined {
    try {
      let mem = guild.members.find((member) => `${member.user.username}#${member.user.discriminator}` === search || member.user.username === search || member.id === search || (message.mentions[0] && member.id === message.mentions[0].id) || (member.nick !== undefined && member.nick === search));
      // eslint-disable-next-line no-mixed-operators
      if (!mem) mem = guild.members.find((member) => `${member.user.username.toLowerCase()}#${member.user.discriminator}` === search.toLowerCase() || member.user.username.toLowerCase() === search.toLowerCase() || member.nick !== undefined && member.nick.toLowerCase() === search.toLowerCase());
      // eslint-disable-next-line no-mixed-operators
      if (!mem) mem = guild.members.find((member) => member.user.username.toLowerCase().includes(search.toLowerCase()) || member.nick !== undefined && member.nick.toLowerCase().includes(search.toLowerCase()));
      if (mem) return mem;
      return undefined;
    } catch {
      return undefined;
    }
  }
}
